import { Base } from "./Base";
import { BadRequestException, ForbiddenException, NotFoundException, throwExpected, UnprocessableEntityException, } from "./exceptions";
class SSOService extends Base {
    /**
     * Get SSO details by business handle
     *
     */
    async getSSOByBusinessHandle(handle) {
        const { apiEndpointAddress, fetch } = this.lensPlatformClient;
        const url = `${apiEndpointAddress}/sso?handle=${handle}`;
        const json = await throwExpected(async () => fetch.get(url), {
            404: () => new NotFoundException("SSO not found"),
            400: () => new BadRequestException("Handle is required"),
        });
        return json;
    }
    /**
     * Get SSO details by domain
     *
     */
    async getSSOByDomain(domain) {
        const { apiEndpointAddress, fetch } = this.lensPlatformClient;
        const url = `${apiEndpointAddress}/sso?domain=${domain}`;
        const json = await throwExpected(async () => fetch.get(url), {
            404: () => new NotFoundException("SSO not found"),
            400: () => new BadRequestException("Domain is required"),
        });
        return json;
    }
    /**
     * Get OIDC SSO configuration
     *
     */
    async getRemoteOIODCConfiguration(remoteOidcConfigUrl) {
        const { apiEndpointAddress, fetch } = this.lensPlatformClient;
        const url = `${apiEndpointAddress}/sso/configuration?url=${remoteOidcConfigUrl}`;
        const json = await throwExpected(async () => fetch.get(url), {
            404: () => new NotFoundException("SSO not found"),
        });
        return json;
    }
    /**
     * Get SSO provider connection link
     *
     */
    async getSSOProviderConnectionLink(providerAlias, clientId) {
        const { apiEndpointAddress, fetch } = this.lensPlatformClient;
        const url = `${apiEndpointAddress}/sso/account-link?provider=${providerAlias}&clientId=${clientId}`;
        const json = await throwExpected(async () => fetch.get(url), {
            404: () => new NotFoundException("SSO provider found"),
            403: (error) => new ForbiddenException(error === null || error === void 0 ? void 0 : error.body.message),
            401: (error) => new ForbiddenException(error === null || error === void 0 ? void 0 : error.body.message),
            422: () => new UnprocessableEntityException(`Failed to retrieve link for provider ${providerAlias}`),
        });
        return json;
    }
}
export { SSOService };
